pub struct AddOption {
pub vote_account: Pubkey,
pub option_account: Pubkey,
pub user: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for AddOption.
Fields
vote_account: Pubkeyoption_account: Pubkeyuser: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AddOptionwhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddOptionwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AddOption
impl ToAccountMetas for AddOption
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AddOption
impl RefUnwindSafe for AddOption
impl Send for AddOption
impl Sync for AddOption
impl Unpin for AddOption
impl UnwindSafe for AddOption