pub struct VoteTopic {
pub topic: String,
pub options_count: u8,
pub applications_deadline: i64,
pub voting_deadline: i64,
pub use_organisation: bool,
pub organisation: Pubkey,
}Fields
topic: Stringoptions_count: u8applications_deadline: i64voting_deadline: i64use_organisation: boolorganisation: PubkeyTrait Implementations
Sourceimpl AccountDeserialize for VoteTopic
impl AccountDeserialize for VoteTopic
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for VoteTopic
impl AccountSerialize for VoteTopic
Sourceimpl BorshDeserialize for VoteTopic
impl BorshDeserialize for VoteTopic
Sourceimpl BorshSerialize for VoteTopicwhere
String: BorshSerialize,
u8: BorshSerialize,
i64: BorshSerialize,
bool: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for VoteTopicwhere
String: BorshSerialize,
u8: BorshSerialize,
i64: BorshSerialize,
bool: BorshSerialize,
Pubkey: BorshSerialize,
Sourceimpl Discriminator for VoteTopic
impl Discriminator for VoteTopic
fn discriminator() -> [u8; 8]