pub struct Voter {
pub voted: bool,
}Fields
voted: boolTrait Implementations
Sourceimpl AccountDeserialize for Voter
impl AccountDeserialize for Voter
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Voter
impl AccountSerialize for Voter
Sourceimpl BorshDeserialize for Voterwhere
bool: BorshDeserialize,
impl BorshDeserialize for Voterwhere
bool: BorshDeserialize,
Sourceimpl BorshSerialize for Voterwhere
bool: BorshSerialize,
impl BorshSerialize for Voterwhere
bool: BorshSerialize,
Sourceimpl Discriminator for Voter
impl Discriminator for Voter
fn discriminator() -> [u8; 8]